@@ -9,7 +9,7 @@
 
 """
 
-__version__ = "0.0.10"
+__version__ = "0.0.11"
 __license__ = "MIT"
 __author__ = "@byteface"
 
@@ -18,6 +18,9 @@ VERSION = __version__
 import os
 import shutil
 import ply.lex as lex
+import warnings
+
+# warnings.warn("Warning...........Message")
 
 
 def term(cmd: str):
@@ -463,6 +466,61 @@ class Lex(object):
         r"\:"
         self.is_read_only = True
 
+    def t_QUESTION(self, t):
+        r"\?"
+        if self.is_extra:
+            # gets the question
+            question = t.lexer.lexdata[t.lexer.lexpos:]
+            if question.find("\n") != -1:
+                question = question[:question.find("\n")]
+            original_length = len(question)
+            question = '\n'.join(question.split('\\n'))
+            if question is not None and question != "":
+                if question[0] == " ":
+                    question = question[1:]
+            # print(question)
+            print("\n")
+            print("Editing: " + self.last_file_created)
+            print("************************************************************")
+            print("Multi-line editor: then Ctrl-D or Ctrl-Z ( windows ) to save.")
+            print("TIP: Press Return for an empty newline BEFORE saving.")
+            print("************************************************************")
+            print("\U0001F4DD Enter/Paste your content.")
+            print("************************************************************")
+
+            # TODO - you can't pass existing file content into the input easily
+            # i do have a branch that can break into vim and return.
+            # but that wont work for windows. so will have a think about it.
+
+            contents = []
+            while True:
+                try:
+                    line = input()
+                except EOFError:
+                    break
+                contents.append(line)
+            content = '\n'.join(contents)
+
+            if tree.TEST_MODE:
+                sslog('TEST_MODE1: skip writing content into this file:', self.last_file_created)
+            else:
+                self.last_file_created = self.last_file_created.strip()  # ensure remove trailing spaces
+                with open(self.last_file_created, "w+", encoding="utf-8") as f:
+                    f.write(content)
+                    sslog(f'    - Writing into {self.last_file_created}')
+                    f.close()
+                # sslog("wrote content into this file:", self.last_file_created)
+
+            t.lexer.skip(original_length)
+        else:
+            filetype = 'folder' if self.is_dir else 'file'
+            print('What would you like the ' + filetype + ' to be called?')
+            line = input()
+            class mock():
+                value = line
+            t = mock()
+            self.t_FILE(t)
+
     def t_TAB(self, t):
         r"[\t]+"
         self.move_back(len(t.value))
@@ -590,6 +648,10 @@ class Lex(object):
             else:
 
                 if not self.delete:
+
+                    # Note - maybe check the path that exists actually is a folder?
+                    # and it was a file created in error. if file then ask to delete it?
+
                     if not os.path.exists(os.path.join(self.cwd, folder_name)):
                         if tree.TEST_MODE:
                             sslog(
